@@ -22,9 +22,18 @@ class AlarmDialog : public QDialog
 {
     Q_OBJECT
 public:
-    enum Unit { Minutes, Hours, Days };
+    enum Unit {
+        Minutes,
+        Hours,
+        Days
+    };
 
-    enum When { BeforeStart = 0, AfterStart, BeforeEnd, AfterEnd };
+    enum When {
+        BeforeStart = 0,
+        AfterStart,
+        BeforeEnd,
+        AfterEnd
+    };
 
 public:
     /**
