@@ -5,11 +5,12 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_INCIDENCECOMPLETIONPRIORITY_H
-#define INCIDENCEEDITOR_INCIDENCECOMPLETIONPRIORITY_H
+#pragma once
 
 #include "incidenceeditor-ng.h"
 
+#include <memory>
+
 namespace Ui
 {
 class EventOrTodoDesktop;
@@ -17,6 +18,8 @@ class EventOrTodoDesktop;
 
 namespace IncidenceEditorNG
 {
+class IncidenceCompletionPriorityPrivate;
+
 class IncidenceCompletionPriority : public IncidenceEditor
 {
     Q_OBJECT
@@ -32,9 +35,7 @@ public:
     bool isDirty() const override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class IncidenceCompletionPriorityPrivate;
+    std::unique_ptr<IncidenceCompletionPriorityPrivate> const d;
 };
 }
-
-#endif
