@@ -215,11 +215,11 @@ QTime IncidenceDateTime::endTime() const
 void IncidenceDateTime::setTimeZonesVisibility(bool visible)
 {
     static const QString tz(i18nc("@action show or hide the time zone widgets", "Time zones"));
-    QString placeholder(QStringLiteral("<a href=\"hide\">&lt;&lt; %1</a>"));
+    QString placeholder(u"<a href=\"hide\">&lt;&lt; %1</a>"_s);
     if (visible) {
         placeholder = placeholder.arg(tz);
     } else {
-        placeholder = QStringLiteral("<a href=\"show\">%1 &gt;&gt;</a>");
+        placeholder = u"<a href=\"show\">%1 &gt;&gt;</a>"_s;
         placeholder = placeholder.arg(tz);
     }
     mUi->mTimeZoneLabel->setText(placeholder);
@@ -384,18 +384,20 @@ void IncidenceDateTime::enableTimeEdits()
     if (mUi->mStartCheck->isChecked()) {
         mUi->mStartTimeEdit->setEnabled(!wholeDayChecked);
         mUi->mTimeZoneComboStart->setEnabled(!wholeDayChecked);
-        if (wholeDayChecked)
+        if (wholeDayChecked) {
             mUi->mTimeZoneComboStart->setFloating(true);
-        else
+        } else {
             mUi->mTimeZoneComboStart->selectTimeZoneFor(mInitialStartDT);
+        }
     }
     if (mUi->mEndCheck->isChecked()) {
         mUi->mEndTimeEdit->setEnabled(!wholeDayChecked);
         mUi->mTimeZoneComboEnd->setEnabled(!wholeDayChecked);
-        if (wholeDayChecked)
+        if (wholeDayChecked) {
             mUi->mTimeZoneComboEnd->setFloating(true);
-        else
+        } else {
             mUi->mTimeZoneComboEnd->selectTimeZoneFor(mInitialEndDT);
+        }
     }
 
     /**
