@@ -6,6 +6,7 @@
 */
 
 #include "ktimezonecombobox.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <KLocalizedString>
 
@@ -16,7 +17,7 @@ using namespace IncidenceEditorNG;
 class IncidenceEditorNG::KTimeZoneComboBoxPrivate
 {
 public:
-    KTimeZoneComboBoxPrivate(KTimeZoneComboBox *parent)
+    explicit KTimeZoneComboBoxPrivate(KTimeZoneComboBox *parent)
         : mParent(parent)
     {
     }
@@ -46,7 +47,7 @@ void KTimeZoneComboBoxPrivate::fillComboBox()
 
     // Put translated zones into the combobox
     for (const auto &z : std::as_const(mZones)) {
-        mParent->addItem(i18n(z.constData()).replace(QLatin1Char('_'), QLatin1Char(' ')));
+        mParent->addItem(i18n(z.constData()).replace(u'_', u' '));
     }
 }
 
@@ -87,10 +88,11 @@ void KTimeZoneComboBox::selectTimeZone(const QTimeZone &zone)
 
 void KTimeZoneComboBox::selectTimeZoneFor(const QDateTime &dateTime)
 {
-    if (dateTime.timeSpec() == Qt::LocalTime)
+    if (dateTime.timeSpec() == Qt::LocalTime) {
         setCurrentIndex(1); // Floating
-    else
+    } else {
         selectTimeZone(dateTime.timeZone());
+    }
 }
 
 QTimeZone KTimeZoneComboBox::selectedTimeZone() const
